@@ -149,15 +149,13 @@ fn it_fails_when_a_system_command_returns_non_zero_exit_code() {
     let template = tempdir()
         .file(
             "system-script.rhai",
-            indoc! {r#"
-                let output = system::command("mkdir", ["invalid_/.dir_name"]);
-            "#},
+            r#"let output = system::command("mkdir", ["invalid_/.dir_name"]);"#,
         )
         .file(
             "cargo-generate.toml",
             indoc! {r#"
-            [hooks]
-            post = ["system-script.rhai"]
+                [hooks]
+                post = ["system-script.rhai"]
             "#},
         )
         .init_git()
@@ -173,10 +171,19 @@ fn it_fails_when_a_system_command_returns_non_zero_exit_code() {
         .assert()
         .failure()
         .stderr(
-            predicates::str::contains(
-                "System command `mkdir invalid_/.dir_name` returned non-zero status",
-            )
-            .from_utf8(),
+            if cfg!(target_os = "linux") {
+                predicates::str::is_match(
+                    r"System command `mkdir invalid_/.dir_name` failed to execute: mkdir: cannot create directory [‘']invalid_/\.dir_name[’']: No such file or directory"
+                ).unwrap().from_utf8()
+            } else if cfg!(target_os = "macos") {
+                predicates::str::is_match(
+                    r"System command `mkdir invalid_/.dir_name` failed to execute: mkdir: invalid_: No such file or directory"
+                ).unwrap().from_utf8()
+            } else { // Windows
+                predicates::str::is_match(
+                    r"System command `mkdir invalid_/.dir_name` failed to execute: The syntax of the command is incorrect\."
+                ).unwrap().from_utf8()
+            }
         );
 }
 
@@ -269,6 +276,8 @@ fn can_change_variables_from_pre_hook() {
         .file(
             "cargo-generate.toml",
             indoc! {r#"
+            [placeholders]
+            multi = {type = "array", prompt="??", choices=["a","b","c"], default=["a","b"]}
             [hooks]
             pre = ["pre-script.rhai"]
             "#},
@@ -277,12 +286,14 @@ fn can_change_variables_from_pre_hook() {
             "pre-script.rhai",
             indoc! {r#"
                 variable::set("foo", "bar");
+                variable::set("multi", ["Q","b"]);
             "#},
         )
         .file(
             "PRE-TEST",
             indoc! {r#"
                 {{foo}};
+                {{multi}};
             "#},
         )
         .init_git()
@@ -294,12 +305,16 @@ fn can_change_variables_from_pre_hook() {
         .arg_git(template.path())
         .arg_name("script-project")
         .current_dir(dir.path())
+        .arg("-d")
+        .arg("multi=a,b")
         .assert()
         .success()
         .stdout(predicates::str::contains("Done!").from_utf8());
 
     assert!(dir.exists("script-project/PRE-TEST"));
-    assert!(dir.read("script-project/PRE-TEST").contains("bar"));
+    let pre_test = dir.read("script-project/PRE-TEST");
+    assert!(pre_test.contains("bar"));
+    assert!(pre_test.contains("Q"));
 }
 
 #[test]
@@ -530,3 +545,34 @@ fn missing_rhai_filter_fails_prints_warnings() {
         .read("filter-project/file_to_expand.txt")
         .contains(r#"{{"filter-script.rhai"|rhai}}"#));
 }
+
+#[test]
+fn should_echo_something() {
+    let template = tempdir()
+        .file(
+            "echo.rhai",
+            indoc! {r#"
+                system::command("echo", ["picard"]);
+            "#},
+        )
+        .file(
+            "cargo-generate.toml",
+            indoc! {r#"
+                [hooks]
+                init = ["echo.rhai"]
+            "#},
+        )
+        .init_git()
+        .build();
+
+    let dir = tempdir().build();
+
+    binary()
+        .arg_git(template.path())
+        .arg_name("foo")
+        .flag_allow_commands()
+        .current_dir(dir.path())
+        .assert()
+        .success()
+        .stdout(predicates::str::contains("picard").from_utf8());
+}
